close all
clear all

K_loss = 0.004; %4.246e-3;
alpha_loss = 2; %3.144;
dens = 7650;


% === Geometry creation ===

% -- open up the base geometry file
openfemm
opendocument('trafo_aniso_lin.fem')

% -- save in a temporary file for purposes of
% -- performing the analysis
mi_saveas('temp.fem')


% mi_modifycircprop('I')

%%

mi_analyze(1);
mi_loadsolution();

probinfo=mo_getprobleminfo;
h = probinfo(3);            % Length of the machine in the into-the-page direction
lengthunits = probinfo(4);
freq = probinfo(2);

%% Losses evaluation


nn = mo_numelements;

z = zeros(nn,1); % Location of the centroid of each element
a = zeros(nn,1); % Area of each element
g = zeros(nn,1); % Block label of each element
b = zeros(nn,2); % matrix that will hold the flux density info

for m = 1:nn
    elm = mo_getelement(m);
    % z is a vector of complex numbers that represents the location of
    % the centroid of each element.
    z(m) = elm(4) + 1j*elm(5);
    % element area in the length units used to draw the geometry
    a(m) = elm(6);
    % group number associated with the element
    g(m) = elm(7);
end

absB = [];
loss = [];

for m = 1:nn
    if(g(m) == 1)			
        b(m,:) = (mo_getb(real(z(m)),imag(z(m))));
        Bx = abs(b(m,1));
        By = abs(b(m,2));

        absB = [absB sqrt(Bx^2 + By^2)];
        Ps = K_loss*freq*sqrt(Bx^2 + By^2)^(alpha_loss);

        % Element data:
        vol = a(m)*h*lengthunits^2;
        weight = vol*dens;          % [m^3.kg/m^3]

        loss = [loss Ps*weight];

    end
end

total_loss = sum(loss);
% mo_zoom(-250,-170,250,170)
% mo_showdensityplot(1, 0, 0, 2, 'mag')

% closefemm
delete('temp.ans')
delete('temp.fem')

%%